==> inspector_monitoring-1.0.1.tar.gz: inspector_monitoring/src/Subscribers/DBEventsSubscriber.php <==
<?php

namespace Drupal\inspector_monitoring\Subscribers;

use Drupal\Core\Database\Event\StatementExecutionEndEvent;
use Drupal\Core\Database\Event\StatementExecutionStartEvent;
use Drupal\inspector_monitoring\Service\Inspector;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Subscriber for database events.
 */
class DBEventsSubscriber implements EventSubscriberInterface {
  use InspectorAwareTrait;

  private const SEGMENT_TYPE_QUERY = 'db_query';

  /**
   * Constructs a new DBEventsSubscriber.
   *
   * @param \Drupal\inspector_monitoring\Service\Inspector $inspector
   *   The inspector service.
   */
  public function __construct(
    Inspector $inspector,
  ) {
    $this->inspector = $inspector;
  }

  /**
   * {@inheritDoc}
   */
  public static function getSubscribedEvents() {
    return [
      StatementExecutionStartEvent::class => ['onStatementStart'],
      StatementExecutionEndEvent::class => ['onStatementEnd'],
    ];
  }

  /**
   * Handles the statement start event.
   *
   * Starts the transaction and the segment.
   *
   * @param \Drupal\Core\Database\Event\StatementExecutionStartEvent $event
   *   The statement start event.
   */
  public function onStatementStart(StatementExecutionStartEvent $event) {
    $this->startSegment(self::SEGMENT_TYPE_QUERY, $event->queryString);
  }

  /**
   * Handles the statement end event.
   *
   * Ends the segment.
   *
   * @param \Drupal\Core\Database\Event\StatementExecutionEndEvent $event
   *   The statement end event.
   */
  public function onStatementEnd(StatementExecutionEndEvent $event) {
    $this->endSegment($event->queryString);
  }

}

==> inspector_monitoring-1.0.2.tar.gz: inspector_monitoring/src/Subscribers/DBEventsSubscriber.php <==
<?php

namespace Drupal\inspector_monitoring\Subscribers;

use Drupal\Core\Database\Event\StatementExecutionEndEvent;
use Drupal\Core\Database\Event\StatementExecutionStartEvent;
use Drupal\inspector_monitoring\Service\Inspector;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Subscriber for database events.
 */
class DBEventsSubscriber implements EventSubscriberInterface {
  use InspectorAwareTrait;

  private const SEGMENT_TYPE_QUERY = 'db_query';

  /**
   * Constructs a new DBEventsSubscriber.
   *
   * @param \Drupal\inspector_monitoring\Service\Inspector $inspector
   *   The inspector service.
   */
  public function __construct(
    Inspector $inspector,
  ) {
    $this->inspector = $inspector;
  }

  /**
   * {@inheritDoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      StatementExecutionStartEvent::class => ['onStatementStart'],
      StatementExecutionEndEvent::class => ['onStatementEnd'],
    ];
  }

  /**
   * Handles the statement start event.
   *
   * Starts the transaction and the segment.
   *
   * @param \Drupal\Core\Database\Event\StatementExecutionStartEvent $event
   *   The statement start event.
   */
  public function onStatementStart(StatementExecutionStartEvent $event) {
    $this->startSegment(self::SEGMENT_TYPE_QUERY, $event->queryString);
  }

  /**
   * Handles the statement end event.
   *
   * Ends the segment.
   *
   * @param \Drupal\Core\Database\Event\StatementExecutionEndEvent $event
   *   The statement end event.
   */
  public function onStatementEnd(StatementExecutionEndEvent $event) {
    $this->endSegment($event->queryString);
  }

}
